import sqlalchemy as sa
from efa.model.outputindicator import Outputindicator
from formbar.form import Form
from ringo.model import Base
from ringo.lib.form import get_form_config



class SIBOutputindicator(Outputindicator):
    """Waskiq specific Outputindicators. Adds some local fields.
    """

    sibparticipation = sa.orm.relation(
        "Participation",
        enable_typechecks=False,
        backref=sa.orm.backref("siboi",
                               uselist=False,
                               cascade="all"))

    # Status of the outputindicators
    status = sa.Column('status', sa.Integer)
    sib_project_module = sa.Column('sib_project_module', sa.String)
    sib_project_module_additional = sa.Column('sib_project_module_additional',
            sa.String)
    sib_project_module_additional_other = sa.Column(
            'sib_project_module_additional_other', sa.String, nullable=True,
            default='')
    access_path = sa.Column('access_path', sa.Integer)
    access_path_others = sa.Column('access_path_others', sa.String, nullable=True, default='')
    lm_employment_supportpurchased = sa.Column('lm_employment_supportpurchased', sa.Integer)
    lm_employment_category_unemployed = sa.Column('lm_employment_category_unemployed', sa.Integer)
    lm_employment_category_unemployement_duration = sa.Column('lm_employment_category_unemployement_duration', sa.Integer)
    lm_employment_category_unemployment_type = sa.Column('lm_employment_category_unemployment_type', sa.Integer)
    lm_employment_category_lookingforwork = sa.Column('lm_employment_category_lookingforwork', sa.Integer)
    lm_employment_category_employed = sa.Column('lm_employment_category_employed', sa.Integer)
    lm_employment_category_underemployed = sa.Column('lm_employment_category_underemployed', sa.Integer)
    lm_employment_category_selfemployed = sa.Column('lm_employment_category_selfemployed', sa.Integer)
    lm_employment_category_school = sa.Column('lm_employment_category_school', sa.Integer)
    lm_employment_category_education_enterprise = sa.Column('lm_employment_category_education_enterprise', sa.Integer)
    lm_employment_category_education_school = sa.Column('lm_employment_category_education_school', sa.Integer)
    lm_employment_category_fulltime_student = sa.Column('lm_employment_category_fulltime_student', sa.Integer)
    lm_employment_category_training = sa.Column('lm_employment_category_training', sa.Integer)
    lm_employment_category_inactive = sa.Column('lm_employment_category_inactive', sa.Integer)
    edu_attainment_school = sa.Column('edu_attainment_school', sa.Integer)
    edu_attainment_school_germany = sa.Column('edu_attainment_school_germany', sa.Integer)
    edu_attainment_school_recognized = sa.Column('edu_attainment_school_recognized', sa.Integer)
    edu_attainment_vocational = sa.Column('edu_attainment_vocational', sa.Integer)
    edu_attainment_vocational_germany = sa.Column('edu_attainment_vocational_germany', sa.Integer)
    edu_attainment_vocational_recognized = sa.Column('edu_attainment_vocational_recognized', sa.Integer)
    work_experience_abroad = sa.Column('work_experience_abroad', sa.Integer)
    work_experience_germany = sa.Column('work_experience_germany', sa.Integer)
    industry = sa.Column('industry', sa.String)
    industry_fp2 = sa.Column('industry_fp2', sa.Integer)
    industry_fp2_erzieherin = sa.Column('industry_fp2_erzieherin', sa.Integer)
    industry_fp2_nurse = sa.Column('industry_fp2_nurse', sa.Integer)
    hh_singleparent_depended = sa.Column('hh_singleparent_depended', sa.Integer)
    hh_employed = sa.Column('hh_employed', sa.Integer)
    born_germany = sa.Column('born_germany', sa.Integer)
    moving_in = sa.Column('moving_in', sa.Integer)
    misc_german_nationality = sa.Column('misc_german_nationality', sa.Integer)
    emigrant = sa.Column('emigrant', sa.Integer)
    country_origin = sa.Column('country_origin', sa.String, nullable=True, default='')
    birthcountry_parents = sa.Column('birthcountry_parents', sa.String, nullable=False, default='')
    birthcountry = sa.Column('birthcountry', sa.String, nullable=False, default='')
    residence_permit_status = sa.Column('residence_permit_status', sa.Integer)
    residence_permit_purpose = sa.Column('residence_permit_purpose', sa.Integer)
    residence_permit_reasons = sa.Column('residence_permit_reasons', sa.Integer)
    integration_course = sa.Column('integration_course', sa.Integer)
    german_knowledge = sa.Column('german_knowledge', sa.Integer)
    german_knowledge_fp2 = sa.Column('german_knowledge_fp2', sa.Integer)
    da_resident = sa.Column('da_resident', sa.Integer)
    jobcenter_job_search = sa.Column('jobcenter_job_search', sa.Integer)
    job_search_assistance = sa.Column('job_search_assistance', sa.Integer)
    job_center_help = sa.Column('job_center_help', sa.Integer)
    children_number_total = sa.Column('children_number_total', sa.Integer)
    children_number = sa.Column('children_number', sa.Integer)
    children_age = sa.Column('children_age', sa.String)

    def is_complete(self):
        if self.status is not None:
            if self.status == 1:
                return True
            else:
                return False
        form_config = get_form_config(self, "update")
        form = Form(form_config, self)
        form.validate()

        status = not form.has_errors() and not form.has_warnings()
        if status:
            self.status = 1
        else:
            self.status = 0
        return status
